Merge branch 'sz/log-names-need-help' of https://github.com/szaydel/fio
[fio.git] / zbd.h
diff --git a/zbd.h b/zbd.h
index ec5d85e1bd50b80756065c0607ddfd8f432e2b9c..08751fd5bf348d43e0efc35f0b891f158eb06299 100644 (file)
--- a/zbd.h
+++ b/zbd.h
@@ -8,6 +8,7 @@
 #define FIO_ZBD_H
 
 #include <inttypes.h>
+#include "fio.h"       /* FIO_MAX_OPEN_ZBD_ZONES */
 #ifdef CONFIG_LINUX_BLKZONED
 #include <linux/blkzoned.h>
 #endif
@@ -56,12 +57,18 @@ struct fio_zone_info {
 /**
  * zoned_block_device_info - zoned block device characteristics
  * @model: Device model.
* @mutex: Protects the modifiable members in this structure (refcount).
  * @zone_size: size of a single zone in units of 512 bytes
+ * @sectors_with_data: total size of data in all zones in units of 512 bytes
  * @zone_size_log2: log2 of the zone size in bytes if it is a power of 2 or 0
  *             if the zone size is not a power of 2.
  * @nr_zones: number of zones
  * @refcount: number of fio files that share this structure
+ * @num_open_zones: number of open zones
+ * @write_cnt: Number of writes since the latest zone reset triggered by
+ *            the zone_reset_frequency fio job parameter.
+ * @open_zones: zone numbers of open zones
  * @zone_info: description of the individual zones
  *
  * Only devices for which all zones have the same size are supported.
@@ -72,9 +79,13 @@ struct zoned_block_device_info {
        enum blk_zoned_model    model;
        pthread_mutex_t         mutex;
        uint64_t                zone_size;
+       uint64_t                sectors_with_data;
        uint32_t                zone_size_log2;
        uint32_t                nr_zones;
        uint32_t                refcount;
+       uint32_t                num_open_zones;
+       uint32_t                write_cnt;
+       uint32_t                open_zones[FIO_MAX_OPEN_ZBD_ZONES];
        struct fio_zone_info    zone_info[0];
 };
 
@@ -86,6 +97,7 @@ bool zbd_unaligned_write(int error_code);
 enum io_u_action zbd_adjust_block(struct thread_data *td, struct io_u *io_u);
 int zbd_do_trim(struct thread_data *td, const struct io_u *io_u);
 void zbd_update_wp(struct thread_data *td, const struct io_u *io_u);
+char *zbd_write_status(const struct thread_stat *ts);
 #else
 static inline void zbd_free_zone_info(struct fio_file *f)
 {
@@ -120,6 +132,11 @@ static inline void zbd_update_wp(struct thread_data *td,
                                 const struct io_u *io_u)
 {
 }
+
+static inline char *zbd_write_status(const struct thread_stat *ts)
+{
+       return NULL;
+}
 #endif
 
 #endif /* FIO_ZBD_H */
@@ -56,12 +57,18 @@ struct fio_zone_info {
  * zoned_block_device_info - zoned block device characteristics
  * @model: Device model.
- * @mutex: Protects the modifiable members in this structure (refcount).
+ * @mutex: Protects the modifiable members in this structure (refcount and
+ *             num_open_zones).
  * @zone_size: size of a single zone in units of 512 bytes